@@ -1,14 +1,10 @@
-;;; gdscript-indent-and-nav.el --- Syntax highlighting for GDScript -*- lexical-binding: t; -*-
+;;; gdscript-indent-and-nav.el --- Syntax highlighting for GDScript  -*- lexical-binding: t; -*-
 
 ;; Copyright (C) 2020-2026 GDQuest and contributors
 
 ;; Author: Nathan Lovato <nathan@gdquest.com>
 ;;         Fabián E. Gallina <fgallina@gnu.org>
 ;; Maintainer: Jen-Chieh Shen <jcs090218@gmail.com>
-;; URL: https://github.com/godotengine/emacs-gdscript-mode/
-;; Package-Requires: ((emacs "26.3"))
-;; Created: Feb 2020
-;; Keywords: languages
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -24,11 +20,12 @@
 ;; along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 ;;; Commentary:
-
+;;
 ;; Functions copies from Emacs 27's built-in python.el to handle indents,
 ;; querying info about the language's symbols or the context at point, and for
 ;; navigation.
 ;; There are dependencies between the *indent*, *info*, and *nav* functions that prevent us from splitting them into separate .el files at the moment.
+;;
 
 ;;; Code:
 
@@ -714,7 +711,7 @@ likely an invalid gdscript file."
                   (when
                       (seq-contains-p possible-opening-blocks
                                       (string-trim (match-string-no-properties 0))
-                                      (lambda (elt e) (string-prefix-p e elt)))
+                                      (lambda (elt e) (string-prefix-p elt e)))
                     (setq opening-blocks (cons (point) opening-blocks))))
                 (when (zerop indentation)
                   (throw 'exit nil)))))
@@ -1422,5 +1419,4 @@ This command assumes point is not in a string or comment."
   (gdscript-nav-up-list (- arg)))
 
 (provide 'gdscript-indent-and-nav)
-
 ;;; gdscript-indent-and-nav.el ends here
