@@ -1,4 +1,4 @@
-;;; gdscript-mode.el --- Major mode for Godot's GDScript language -*- lexical-binding: t; -*-
+;;; gdscript-mode.el --- Major mode for Godot's GDScript language  -*- lexical-binding: t; -*-
 
 ;; Copyright (C) 2020-2026 GDQuest and contributors
 
@@ -6,9 +6,9 @@
 ;;         Fabián E. Gallina <fgallina@gnu.org>
 ;; Maintainer: Jen-Chieh Shen <jcs090218@gmail.com>
 ;; URL: https://github.com/godotengine/emacs-gdscript-mode/
-;; Package-Version: 20260123.1636
-;; Package-Revision: eac71fb88bc6
-;; Package-Requires: ((emacs "26.3"))
+;; Package-Version: 20260202.556
+;; Package-Revision: dd44f1dfa541
+;; Package-Requires: ((emacs "28.1"))
 ;; Created: Jan 2020
 ;; Keywords: languages
 
@@ -55,6 +55,7 @@
 (add-to-list 'auto-mode-alist '("\\.tscn\\'" . conf-toml-mode))
 ;;;###autoload
 (add-to-list 'auto-mode-alist '("\\.tres\\'" . conf-toml-mode))
+
 ;;;###autoload
 (with-eval-after-load 'eglot
   (defvar eglot-server-programs)
@@ -63,52 +64,53 @@
     (push (cons 'gdscript-mode #'gdscript-eglot-contact)
           eglot-server-programs)))
 
-(defvar gdscript-mode-map (let ((map (make-sparse-keymap)))
-                            ;; Movement
-                            (define-key map [remap backward-sentence] 'gdscript-nav-backward-block)
-                            (define-key map [remap forward-sentence] 'gdscript-nav-forward-block)
-                            (define-key map [remap backward-up-list] 'gdscript-nav-backward-up-list)
-                            (define-key map [remap mark-defun] 'gdscript-mark-defun)
-                            (define-key map (kbd "C-c C-j") 'imenu)
-                            ;; Indent specific
-                            (define-key map "\177" 'gdscript-indent-dedent-line-backspace)
-                            (define-key map (kbd "<backtab>") 'gdscript-indent-dedent-line)
-                            (define-key map (kbd "\t") 'company-complete)
-                            ;; Insertion.
-                            (define-key map (kbd "C-c i") 'gdscript-completion-insert-file-path-at-point)
-                            ;; Formatting.
-                            (define-key map (kbd "C-c C-f r") 'gdscript-format-region)
-                            (define-key map (kbd "C-c C-f b") 'gdscript-format-buffer)
-                            ;; Run in Godot.
-                            (define-key map (kbd "C-c C-r p") 'gdscript-godot-open-project-in-editor)
-                            (define-key map (kbd "C-c C-r r") 'gdscript-godot-run-project)
-                            (define-key map (kbd "<f5>") 'gdscript-godot-run-project)
-                            (define-key map (kbd "C-c C-r d") 'gdscript-godot-run-project-debug)
-                            (define-key map (kbd "C-c C-r s") 'gdscript-godot-run-current-scene)
-                            (define-key map (kbd "<f6>") 'gdscript-godot-run-current-scene)
-                            (define-key map (kbd "C-c C-r q") 'gdscript-godot-run-current-scene-debug)
-                            (define-key map (kbd "C-c C-r e") 'gdscript-godot-edit-current-scene)
-                            (define-key map (kbd "C-c C-r x") 'gdscript-godot-run-current-script)
-                            ;; Docs.
-                            (define-key map (kbd "C-c C-b a") 'gdscript-docs-browse-api)
-                            (define-key map (kbd "C-c C-b o") 'gdscript-docs-browse-symbol-at-point)
-                            (define-key map (kbd "C-c C-b s") 'gdscript-docs-online-search-api)
-                            ;; Hydra
-                            (define-key map (kbd "C-c r") 'gdscript-hydra-show)
-                            ;; Debugger
-                            (define-key map (kbd "C-c C-d C-d s") 'gdscript-debug-display-stack-frame-vars-buffer)
-                            (define-key map (kbd "C-c C-d C-d d") 'gdscript-debug-display-stack-dump-buffer)
-                            (define-key map (kbd "C-c C-d C-d b") 'gdscript-debug-display-breakpoint-buffer)
-                            (define-key map (kbd "C-c C-d C-d i") 'gdscript-debug-display-inspector-buffer)
-                            (define-key map (kbd "<f9>") 'gdscript-debug-toggle-breakpoint)
-                            (define-key map (kbd "C-c C-d q") 'gdscript-debug-make-server)
-                            (define-key map (kbd "C-c C-d n") 'gdscript-debug-next)
-                            (define-key map (kbd "C-c C-d c") 'gdscript-debug-continue)
-                            (define-key map (kbd "<f7>") 'gdscript-debug-continue)
-                            (define-key map (kbd "C-c C-d s") 'gdscript-debug-step)
-                            ;; Debugger Hydra
-                            (define-key map (kbd "C-c n") 'gdscript-debug-hydra)
-                            map)
+(defvar gdscript-mode-map
+  (let ((map (make-sparse-keymap)))
+    ;; Movement
+    (define-key map [remap backward-sentence] 'gdscript-nav-backward-block)
+    (define-key map [remap forward-sentence] 'gdscript-nav-forward-block)
+    (define-key map [remap backward-up-list] 'gdscript-nav-backward-up-list)
+    (define-key map [remap mark-defun] 'gdscript-mark-defun)
+    (define-key map (kbd "C-c C-j") 'imenu)
+    ;; Indent specific
+    (define-key map "\177" 'gdscript-indent-dedent-line-backspace)
+    (define-key map (kbd "<backtab>") 'gdscript-indent-dedent-line)
+    (define-key map (kbd "\t") 'company-complete)
+    ;; Insertion.
+    (define-key map (kbd "C-c i") 'gdscript-completion-insert-file-path-at-point)
+    ;; Formatting.
+    (define-key map (kbd "C-c C-f r") 'gdscript-format-region)
+    (define-key map (kbd "C-c C-f b") 'gdscript-format-buffer)
+    ;; Run in Godot.
+    (define-key map (kbd "C-c C-r p") 'gdscript-godot-open-project-in-editor)
+    (define-key map (kbd "C-c C-r r") 'gdscript-godot-run-project)
+    (define-key map (kbd "<f5>") 'gdscript-godot-run-project)
+    (define-key map (kbd "C-c C-r d") 'gdscript-godot-run-project-debug)
+    (define-key map (kbd "C-c C-r s") 'gdscript-godot-run-current-scene)
+    (define-key map (kbd "<f6>") 'gdscript-godot-run-current-scene)
+    (define-key map (kbd "C-c C-r q") 'gdscript-godot-run-current-scene-debug)
+    (define-key map (kbd "C-c C-r e") 'gdscript-godot-edit-current-scene)
+    (define-key map (kbd "C-c C-r x") 'gdscript-godot-run-current-script)
+    ;; Docs.
+    (define-key map (kbd "C-c C-b a") 'gdscript-docs-browse-api)
+    (define-key map (kbd "C-c C-b o") 'gdscript-docs-browse-symbol-at-point)
+    (define-key map (kbd "C-c C-b s") 'gdscript-docs-online-search-api)
+    ;; Hydra
+    (define-key map (kbd "C-c r") 'gdscript-hydra-show)
+    ;; Debugger
+    (define-key map (kbd "C-c C-d C-d s") 'gdscript-debug-display-stack-frame-vars-buffer)
+    (define-key map (kbd "C-c C-d C-d d") 'gdscript-debug-display-stack-dump-buffer)
+    (define-key map (kbd "C-c C-d C-d b") 'gdscript-debug-display-breakpoint-buffer)
+    (define-key map (kbd "C-c C-d C-d i") 'gdscript-debug-display-inspector-buffer)
+    (define-key map (kbd "<f9>") 'gdscript-debug-toggle-breakpoint)
+    (define-key map (kbd "C-c C-d q") 'gdscript-debug-make-server)
+    (define-key map (kbd "C-c C-d n") 'gdscript-debug-next)
+    (define-key map (kbd "C-c C-d c") 'gdscript-debug-continue)
+    (define-key map (kbd "<f7>") 'gdscript-debug-continue)
+    (define-key map (kbd "C-c C-d s") 'gdscript-debug-step)
+    ;; Debugger Hydra
+    (define-key map (kbd "C-c n") 'gdscript-debug-hydra)
+    map)
   "Keymap for `gdscript-mode'.")
 
 (defun gdscript-hideshow-forward-sexp-function (_arg)
@@ -231,5 +233,4 @@ already marked."
                   (1+ (/ (current-indentation) gdscript-indent-offset)))))
 
 (provide 'gdscript-mode)
-
 ;;; gdscript-mode.el ends here
