@@ -1,14 +1,10 @@
-;;; gdscript-rx.el --- Regex for GDScript -*- lexical-binding: t; -*-
+;;; gdscript-rx.el --- Regex for GDScript  -*- lexical-binding: t; -*-
 
 ;; Copyright (C) 2020-2026 GDQuest and contributors
 
 ;; Author: Nathan Lovato <nathan@gdquest.com>
 ;;         Fabián E. Gallina <fgallina@gnu.org>
 ;; Maintainer: Jen-Chieh Shen <jcs090218@gmail.com>
-;; URL: https://github.com/godotengine/emacs-gdscript-mode/
-;; Package-Requires: ((emacs "26.3"))
-;; Created: Feb 2020
-;; Keywords: languages
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -1444,47 +1440,46 @@ following constructs:
 (defmacro gdscript-rx (&rest regexps)
   "Gdscript mode specialized rx macro.
 This variant of `rx' supports common Gdscript named REGEXPS."
-  `(gdscript-rx-let (
-                     (block-start
-                      (or (seq (or "if" "elif" "while" "func") (+? (not ":")) ":")
-                          (seq (zero-or-more nonl)
-                               ":"
-                               (or (seq (zero-or-more " ") eol)
-                                   (seq (zero-or-more " ") "#" (zero-or-more nonl) eol)))))
-                     (dedenter          (seq symbol-start
-                                             (or "elif" "else")
-                                             symbol-end))
-                     (block-ender       (seq symbol-start
-                                             (or "break" "continue" "pass" "return")
-                                             symbol-end))
-                     (defun             (seq symbol-start
-                                             (or "func" "class" "static func")
-                                             symbol-end))
-                     (symbol-name       (seq (any letter ?_) (* (any word ?_))))
-                     (open-paren        (or "{" "[" "("))
-                     (close-paren       (or "}" "]" ")"))
-                     (simple-operator   (any ?+ ?- ?/ ?& ?^ ?~ ?| ?* ?< ?> ?= ?%))
-                     (not-simple-operator (not simple-operator))
-                     ;; TODO: clean up operators that don't exist in GDScript
-                     (operator          (or "==" ">=" "is" "not"
-                                            "**" "//" "<<" ">>" "<=" "!="
-                                            "+" "-" "/" "&" "^" "~" "|" "*" "<" ">"
-                                            "=" "%"))
-                     (assignment-operator (or "+=" "-=" "*=" "/=" "//=" "%=" "**="
-                                              ">>=" "<<=" "&=" "^=" "|="
-                                              "="))
-                     (string-delimiter  (seq
-                                         ;; Match even number of backslashes.
-                                         (or (not (any ?\\ ?\' ?\")) point
-                                             ;; Quotes might be preceded by an
-                                             ;; escaped quote.
-                                             (and (or (not (any ?\\)) point) ?\\
-                                                  (* ?\\ ?\\) (any ?\' ?\")))
-                                         (* ?\\ ?\\)
-                                         ;; Match single or triple quotes of any kind.
-                                         (group (or  "\"\"\"" "\"" "'''" "'")))))
+  `(gdscript-rx-let
+       ((block-start
+         (or (seq (or "if" "elif" "while" "func") (+? (not ":")) ":")
+             (seq (zero-or-more nonl)
+                  ":"
+                  (or (seq (zero-or-more " ") eol)
+                      (seq (zero-or-more " ") "#" (zero-or-more nonl) eol)))))
+        (dedenter          (seq symbol-start
+                                (or "elif" "else")
+                                symbol-end))
+        (block-ender       (seq symbol-start
+                                (or "break" "continue" "pass" "return")
+                                symbol-end))
+        (defun             (seq symbol-start
+                                (or "func" "class" "static func")
+                                symbol-end))
+        (symbol-name       (seq (any letter ?_) (* (any word ?_))))
+        (open-paren        (or "{" "[" "("))
+        (close-paren       (or "}" "]" ")"))
+        (simple-operator   (any ?+ ?- ?/ ?& ?^ ?~ ?| ?* ?< ?> ?= ?%))
+        (not-simple-operator (not simple-operator))
+        ;; TODO: clean up operators that don't exist in GDScript
+        (operator          (or "==" ">=" "is" "not"
+                               "**" "//" "<<" ">>" "<=" "!="
+                               "+" "-" "/" "&" "^" "~" "|" "*" "<" ">"
+                               "=" "%"))
+        (assignment-operator (or "+=" "-=" "*=" "/=" "//=" "%=" "**="
+                                 ">>=" "<<=" "&=" "^=" "|="
+                                 "="))
+        (string-delimiter  (seq
+                            ;; Match even number of backslashes.
+                            (or (not (any ?\\ ?\' ?\")) point
+                                ;; Quotes might be preceded by an
+                                ;; escaped quote.
+                                (and (or (not (any ?\\)) point) ?\\
+                                     (* ?\\ ?\\) (any ?\' ?\")))
+                            (* ?\\ ?\\)
+                            ;; Match single or triple quotes of any kind.
+                            (group (or  "\"\"\"" "\"" "'''" "'")))))
      (gdscript-rx-build-rx ,@regexps)))
 
 (provide 'gdscript-rx)
-
 ;;; gdscript-rx.el ends here
