@@ -1,12 +1,10 @@
-;;; gdscript-ts-mode.el --- Summary  -*- lexical-binding: t -*-
+;;; gdscript-ts-mode.el --- Major mode for GDScript using Tree-sitter  -*- lexical-binding: t -*-
 
 ;; Copyright (C) 2023-2026 GDQuest and contributors
 
 ;; Author: xiliuya <xiliuya@aliyun.com>
 ;; Maintainer: xiliuya <xiliuya@aliyun.com>
 ;;             Jen-Chieh Shen <jcs090218@gmail.com>
-;; URL: https://github.com/godotengine/emacs-gdscript-mode/
-;; Created: 2023-05-22 19:14:43
 
 ;; Keywords: languages
 ;; Package-Requires: ((emacs "26.3"))
@@ -36,6 +34,23 @@
 (when (version< "29" emacs-version)
   (require 'treesit))
 
+(defvar treesit-font-lock-feature-list)
+(defvar treesit-font-lock-settings)
+(defvar treesit-defun-type-regexp)
+(defvar treesit-defun-name-function)
+
+(declare-function treesit-font-lock-rules nil "ext:treesit.el")
+(declare-function treesit-search-subtree nil "ext:treesit.el")
+(declare-function treesit-node-type nil "ext:treesit.el")
+(declare-function treesit-defun-name nil "ext:treesit.el")
+(declare-function treesit-node-start nil "ext:treesit.el")
+(declare-function treesit-buffer-root-node nil "ext:treesit.el")
+(declare-function treesit-induce-sparse-tree nil "ext:treesit.el")
+(declare-function treesit-ready-p nil "ext:treesit.el")
+(declare-function treesit-parser-create nil "ext:treesit.el")
+(declare-function treesit-major-mode-setup nil "ext:treesit.el")
+(declare-function treesit-node-text nil "ext:treesit.el")
+
 
 ;;; Imenu
 
